# -*- coding: utf-8 -*-

"""Test Logos

Utilisation :
    créer les variables d'environnement: (indiquer les valeurs
    pour le serveur ScoDoc que vous voulez interroger)

    export SCODOC_URL="https://scodoc.xxx.net/"
    export SCODOC_USER="xxx"
    export SCODOC_PASSWD="xxx"
    export CHECK_CERTIFICATE=0 # ou 1 si serveur de production avec certif SSL valide

    (on peut aussi placer ces valeurs dans un fichier .env du répertoire tests/api).

    Lancer :
        pytest tests/api/test_api_etudiants.py
"""
from random import randint

import requests

from tests.api.setup_test_api import API_URL, CHECK_CERTIFICATE, api_headers
from tests.api.tools_test_api import verify_fields

# etudiants_courant
def test_etudiants_courant(api_headers):
    """
    Route: /etudiants/courant
    """
    fields = [
        "id",
        "nip",
        "nom",
        "nom_usuel",
        "prenom",
        "civilite",
    ]

    r = requests.get(
        API_URL + "/etudiants/courant",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    etudiants = r.json()
    assert len(etudiants) == 16  # XXX HARDCODED

    etud = etudiants[-1]

    fields_ok = verify_fields(etud, fields)

    assert fields_ok is True

    ########## Version long ################

    fields_long = [
        "civilite",
        "code_ine",
        "code_nip",
        "date_naissance",
        "email",
        "emailperso",
        "etudid",
        "nom",
        "prenom",
        "nomprenom",
        "lieu_naissance",
        "dept_naissance",
        "nationalite",
        "boursier",
        "id",
        "codepostaldomicile",
        "paysdomicile",
        "telephonemobile",
        "typeadresse",
        "domicile",
        "villedomicile",
        "telephone",
        "fax",
        "description",
    ]

    r = requests.get(
        API_URL + "/etudiants/courant/long",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    etudiants = r.json()
    assert len(etudiants) == 16  # HARDCODED

    etud = etudiants[-1]
    fields_ok = verify_fields(etud, fields_long)

    assert fields_ok is True


def test_etudiant(api_headers):
    """
    Route:
    """
    fields = [
        "civilite",
        "code_ine",
        "code_nip",
        "date_naissance",
        "email",
        "emailperso",
        "etudid",
        "nom",
        "prenom",
        "nomprenom",
        "lieu_naissance",
        "dept_naissance",
        "nationalite",
        "boursier",
        "id",
        "domicile",
        "villedomicile",
        "telephone",
        "fax",
        "description",
        "codepostaldomicile",
        "paysdomicile",
        "telephonemobile",
        "typeadresse",
    ]

    ######### Test etudid #########
    r = requests.get(
        API_URL + "/etudiant/etudid/1",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    etud = r.json()
    assert len(etud) == 24  # ? HARDCODED

    fields_ok = verify_fields(etud, fields)
    assert fields_ok is True

    ######### Test code nip #########

    r = requests.get(
        API_URL + "/etudiant/nip/1",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    etud = r.json()
    assert len(etud) == 24
    fields_ok = verify_fields(etud, fields)
    assert fields_ok is True

    ######### Test code ine #########

    r = requests.get(
        API_URL + "/etudiant/ine/1",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    etud = r.json()
    assert len(etud) == 24
    fields_ok = verify_fields(etud, fields)
    assert fields_ok is True


def test_etudiant_formsemestres(api_headers):
    """
    Route: /etudiant/etudid/<etudid:int>/formsemestres
    """
    fields = [
        "date_fin",
        "resp_can_edit",
        "dept_id",
        "etat",
        "resp_can_change_ens",
        "id",
        "modalite",
        "ens_can_edit_eval",
        "formation_id",
        "gestion_compensation",
        "elt_sem_apo",
        "semestre_id",
        "bul_hide_xml",
        "elt_annee_apo",
        "titre",
        "block_moyennes",
        "scodoc7_id",
        "date_debut",
        "gestion_semestrielle",
        "bul_bgcolor",
        "formsemestre_id",
        "titre_num",
        "date_debut_iso",
        "date_fin_iso",
        "responsables",
    ]

    ######### Test etudid #########

    r = requests.get(
        API_URL + "/etudiant/etudid/1/formsemestres",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    formsemestres = r.json()
    assert len(formsemestres) == 1

    formsemestre = formsemestres[0]

    fields_ok = verify_fields(formsemestre, fields)
    assert fields_ok is True

    ######### Test code nip #########
    r = requests.get(
        API_URL + "/etudiant/nip/1/formsemestres",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    formsemestres = r.json()
    assert len(formsemestres) == 1

    formsemestre = formsemestres[0]

    fields_ok = verify_fields(formsemestre, fields)
    assert fields_ok is True

    ######### Test code ine #########
    r = requests.get(
        API_URL + "/etudiant/ine/1/formsemestres",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    formsemestres = r.json()
    assert len(formsemestres) == 1

    formsemestre = formsemestres[0]

    fields_ok = verify_fields(formsemestre, fields)
    assert fields_ok is True


def test_etudiant_bulletin_semestre(api_headers):
    """
    Route: /etudiant/etudid/<etudid>/formsemestre/<formsemestre_id>/bulletin
    """
    ######### Test etudid #########

    r = requests.get(
        API_URL + "/etudiant/etudid/1/formsemestre/1/bulletin",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    bul = r.json()
    assert len(bul) == 13  # HARDCODED

    ######### Test code nip #########

    r = requests.get(
        API_URL + "/etudiant/nip/1/formsemestre/1/bulletin",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    bul = r.json()
    assert len(bul) == 13  # HARDCODED

    ######### Test code ine #########
    r = requests.get(
        API_URL + "/etudiant/ine/1/formsemestre/1/bulletin",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    bul = r.json()
    assert len(bul) == 13  # HARDCODED


def test_etudiant_groups(api_headers):
    """
    Route:
    /etudiant/etudid/<int:etudid>/formsemestre/<int:formsemestre_id>/groups
    """
    fields = [
        "partition_id",
        "id",
        "formsemestre_id",
        "partition_name",
        "numero",
        "bul_show_rank",
        "show_in_lists",
        "group_id",
        "group_name",
    ]

    ######### Test etudid #########

    r = requests.get(
        API_URL + "/etudiant/etudid/1/formsemestre/1/groups",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    groups = r.json()
    assert len(groups) == 1  # dans un seul groupe
    group = groups[0]
    fields_ok = verify_fields(group, fields)
    assert fields_ok is True

    ######### Test code nip #########
    r = requests.get(
        API_URL + "/etudiant/nip/1/formsemestre/1/groups",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    groups = r.json()
    assert len(groups) == 1  # dans un seul groupe
    group = groups[0]
    fields_ok = verify_fields(group, fields)
    assert fields_ok is True

    ######### Test code ine #########
    r = requests.get(
        API_URL + "/etudiant/ine/1/formsemestre/1/groups",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    groups = r.json()
    assert len(groups) == 1  # dans un seul groupe
    group = groups[0]
    fields_ok = verify_fields(group, fields)
    assert fields_ok is True
